@@ -64,11 +64,7 @@ class SignaldAPI(SignaldGeneratedAPI):
             return uri, linking_successful
 
     async def verify(self, username: str, code: str):
-        await self.get_response_and_wait_for(
-            request={"type": "verify", "username": username, "code": code},
-            validator=lambda response: response.get("type") == "verified"
-            and response.get("data", {}).get("username") == username,
-        )
+        await self.get_response({"type": "verify", "username": username, "code": code})
 
     async def register(self, username: str, captcha: str = None):
         """
@@ -79,11 +75,7 @@ class SignaldAPI(SignaldGeneratedAPI):
         payload = {"type": "register", "username": username}
         if captcha is not None:
             payload["captcha"] = captcha
-        await self.get_response_and_wait_for(
-            request={"type": "register", "username": username},
-            validator=lambda response: response.get("type") == "verification_required"
-            and response.get("data", {}).get("username") == username,
-        )
+        await self.get_response(payload)
 
     async def list_accounts(self) -> JsonAccountListv0:
         data = await self.get_response({"type": "list_accounts"})
